Here's the documentation for the functions in the `ibl_axd_pro.swagger.dart` SDK:

### Get Organization Credential
```dart
Function: _apiAiAccountOrgsOrgCredentialGet()
Description: Retrieves the credential for a specified organization.
HTTP Method: GET
Endpoint: /api/ai/account/orgs/${org}/credential/
Parameters: 
  - org: String // The organization identifier.
Headers: {'Authorization': 'Bearer YOUR_ACCESS_TOKEN'} // If applicable
Return Type: Future<Response<LLMCredential>> // LLMCredential is the expected return type.
Usage: 
var orgCredentialResponse = await iblAxdPro._apiAiAccountOrgsOrgCredentialGet(org: 'orgId');
```

### Post Organization Credential
```dart
Function: _apiAiAccountOrgsOrgCredentialPost()
Description: Creates or updates the credential for a specified organization.
HTTP Method: POST
Endpoint: /api/ai/account/orgs/${org}/credential/
Parameters: 
  - org: String // The organization identifier.
  - body: LLMCredential // Credential details to be updated or created.
Headers: {'Authorization': 'Bearer YOUR_ACCESS_TOKEN'} // If applicable
Return Type: Future<Response<LLMCredential>>
Usage: 
var orgCredentialUpdateResponse = await iblAxdPro._apiAiAccountOrgsOrgCredentialPost(org: 'orgId', body: credentialDetails);
```

### Patch Organization Credential
```dart
Function: _apiAiAccountOrgsOrgCredentialPatch()
Description: Partially updates the credential for a specified organization.
HTTP Method: PATCH
Endpoint: /api/ai/account/orgs/${org}/credential/
Parameters: 
  - org: String // The organization identifier.
  - body: PatchedLLMCredential // Partial credential details to be updated.
Headers: {'Authorization': 'Bearer YOUR_ACCESS_TOKEN'} // If applicable
Return Type: Future<Response<LLMCredential>>
Usage: 
var orgCredentialPatchResponse = await iblAxdPro._apiAiAccountOrgsOrgCredentialPatch(org: 'orgId', body: patchedCredentialDetails);
```

### Get Organization Platform Metadata
```dart
Function: _apiAiAccountOrgsOrgPlatformMetadataGet()
Description: Retrieves platform metadata for a specified organization.
HTTP Method: GET
Endpoint: /api/ai/account/orgs/${org}/platform-metadata/
Parameters: 
  - org: String // The organization identifier.
Headers: {'Authorization': 'Bearer YOUR_ACCESS_TOKEN'} // If applicable
Return Type: Future<Response<IBLAIPlatformMeta>>
Usage: 
var orgPlatformMetadataResponse = await iblAxdPro._apiAiAccountOrgsOrgPlatformMetadataGet(org: 'orgId');
```

Continuing with the documentation for the functions in the `ibl_axd_pro.swagger.dart` SDK:

### Put Organization Platform Metadata
```dart
Function: _apiAiAccountOrgsOrgPlatformMetadataPut()
Description: Updates platform metadata for a specified organization.
HTTP Method: PUT
Endpoint: /api/ai/account/orgs/${org}/platform-metadata/
Parameters: 
  - org: String // The organization identifier.
  - body: IBLAIPlatformMeta // Platform metadata details to be updated.
Headers: {'Authorization': 'Bearer YOUR_ACCESS_TOKEN'} // If applicable
Return Type: Future<Response<IBLAIPlatformMeta>>
Usage: 
var orgPlatformMetadataPutResponse = await iblAxdPro._apiAiAccountOrgsOrgPlatformMetadataPut(org: 'orgId', body: platformMetaData);
```

### Get Org Tokens
```dart
Function: _apiAiAccountOrgsOrgTokensGet()
Description: Retrieves API token costs for a specified organization.
HTTP Method: GET
Endpoint: /api/ai/account/orgs/${org}/tokens/
Parameters: 
  - org: String // The organization identifier.
Headers: {'Authorization': 'Bearer YOUR_ACCESS_TOKEN'} // If applicable
Return Type: Future<Response<List<APITokenCost>>>
Usage: 
var apiTokenCostsResponse = await iblAxdPro._apiAiAccountOrgsOrgTokensGet(org: 'orgId');
```

### Get Retriever Document Embedding
```dart
Function: _apiAiIndexOrgsOrgUsersUserIdDocumentsDocumentIdRetrieverDocumentsGet()
Description: Retrieves the document embedding for a specific document in an organization.
HTTP Method: GET
Endpoint: /api/ai/index/orgs/${org}/users/${userId}/documents/${documentId}/retriever_documents/
Parameters: 
  - org: String
  - userId: String
  - documentId: String
Headers: {'Authorization': 'Bearer YOUR_ACCESS_TOKEN'} // If applicable
Return Type: Future<Response<RetrieverDocumentEmbedding>>
Usage: 
var documentEmbeddingResponse = await iblAxdPro._apiAiIndexOrgsOrgUsersUserIdDocumentsDocumentIdRetrieverDocumentsGet(org: 'orgId', userId: 'userId', documentId: 'documentId');
```

Continuing with the documentation for the functions in the `ibl_axd_pro.swagger.dart` SDK:

### Put Retriever Document Embedding
```dart
Function: _apiAiIndexOrgsOrgUsersUserIdDocumentsDocumentIdRetrieverDocumentsPut()
Description: Updates the document embedding for a specific document in an organization.
HTTP Method: PUT
Endpoint: /api/ai/index/orgs/${org}/users/${userId}/documents/${documentId}/retriever_documents/
Parameters: 
  - org: String
  - userId: String
  - documentId: String
  - body: RetrieverDocumentEmbeddingRequest // Details of the document embedding to be updated.
Headers: {'Authorization': 'Bearer YOUR_ACCESS_TOKEN'} // If applicable
Return Type: Future<Response<RetrieverDocumentEmbedding>>
Usage: 
var documentEmbeddingPutResponse = await iblAxdPro._apiAiIndexOrgsOrgUsersUserIdDocumentsDocumentIdRetrieverDocumentsPut(org: 'orgId', userId: 'userId', documentId: 'documentId', body: embeddingDetails);
```

### Multilingual Retriever Train Post
```dart
Function: _apiAiIndexOrgsOrgUsersUserIdMultilingualRetrieverTrainPost()
Description: Trains the multilingual retriever model for a user in an organization.
HTTP Method: POST
Endpoint: /api/ai/index/orgs/${org}/users/${userId}/multilingual_retriever_train/
Parameters: 
  - org: String
  - userId: String
  - body: RetreiverTrainViewRequest // Training request details.
Headers: {'Authorization': 'Bearer YOUR_ACCESS_TOKEN'} // If applicable
Return Type: Future<Response<RetreiverTrainViewResponse>>
Usage: 
var multilingualRetrieverTrainResponse = await iblAxdPro._apiAiIndexOrgsOrgUsersUserIdMultilingualRetrieverTrainPost(org: 'orgId', userId: 'userId', body: trainViewRequest);
```

### Get Pathway Retriever Documents
```dart
Function: _apiAiIndexOrgsOrgUsersUserIdPathwaysPathwayRetrieverDocumentsGet()
Description: Retrieves retriever documents for a specific pathway.
HTTP Method: GET
Endpoint: /api/ai/index/orgs/${org}/users/${userId}/pathways/${pathway}/retriever_documents/
Parameters: 
  - org: String
  - userId: String
  - pathway: String // Pathway identifier.
Headers: {'Authorization': 'Bearer YOUR_ACCESS_TOKEN'} // If applicable
Return Type: Future<Response<RetrieverDocumentEmbedding>>
Usage: 
var pathwayRetrieverDocumentsResponse = await iblAxdPro._apiAiIndexOrgsOrgUsersUserIdPathwaysPathwayRetrieverDocumentsGet(org: 'orgId', userId: 'userId', pathway: 'pathwayId');
```

### Retriever Search Post
```dart
Function: _apiAiIndexOrgsOrgUsersUserIdRetrieverSearchPost()
Description: Performs a search using the retriever model for a user in an organization.
HTTP Method: POST
Endpoint: /api/ai/index/orgs/${org}/users/${userId}/retriever_search/
Parameters: 
  - org: String
  - userId: String
  - body: RetrieverRequestSearch // Search request details.
Headers: {'Authorization': 'Bearer YOUR_ACCESS_TOKEN'} // If applicable
Return Type: Future<Response<RetrieverResponseSearch>>
Usage: 
var retrieverSearchResponse = await iblAxdPro._apiAiIndexOrgsOrgUsersUserIdRetrieverSearchPost(org: 'orgId', userId: 'userId', body: searchRequest);
```

