# ibl_mobile_core_frontend SDK Documentation
## Overview
This SDK, a part of `ibl_web_pro.swagger.dart`, facilitates interaction with the Ibl Web Pro API in a Flutter application. It supports user management, product handling, session management, and more.

## Importing and Initializing the SDK
### Import SDK:
```dart
import 'path_to_ibl_mobile_core_frontend/ibl_web_pro.swagger.dart';
```
### Initialize SDK:
```dart
final iblWebPro = _$IblWebPro(ChopperClient(baseUrl: 'YOUR_API_BASE_URL'));
```

## SDK Functions

### Create User
```dart

## SDK Functions Documentation

### 1. Create User
```dart
Function: _apiIblV1UsersPost()
Description: Creates a new user in the system.
HTTP Method: POST
Endpoint: /api/ibl/v1/users
Parameters: [UserDetails userDetails]
Headers: {'Authorization': 'Bearer YOUR_ACCESS_TOKEN'} 
Return Type: Future<Response<User>> 
Usage: 
var createUserResponse = await iblWebPro._apiIblV1UsersPost(userDetails);
```

### 2. Create Checkout Session
```dart
Function: _apiIblV1CreateCheckoutSessionPost()
Description: Initiates a new checkout session.
HTTP Method: POST
Endpoint: /api/ibl/v1/create_checkout_session
Parameters: [SessionDetails sessionDetails]
Headers: {'Authorization': 'Bearer YOUR_ACCESS_TOKEN'} 
Return Type: Future<Response<Session>> 
Usage: 
var createSessionResponse = await iblWebPro._apiIblV1CreateCheckoutSessionPost(sessionDetails);
```

### 3. Get All Products
```dart
Function: _apiIblV1GetAllProductsGet()
Description: Retrieves all products available.
HTTP Method: GET
Endpoint: /api/ibl/v1/get_all_products
Parameters: None
Headers: {'Authorization': 'Bearer YOUR_ACCESS_TOKEN'} 
Return Type: Future<Response<List<Product>>> 
Usage: 
var allProductsResponse = await iblWebPro._apiIblV1GetAllProductsGet();
```

### 4. Get Product Price
```dart
Function: _apiIblV1GetProductPriceGet()
Description: Fetches the price of a specific product.
HTTP Method: GET
Endpoint: /api/ibl/v1/get_product_price
Parameters: [String productId]
Headers: {'Authorization': 'Bearer YOUR_ACCESS_TOKEN'} 
Return Type: Future<Response<PriceDetails>> 
Usage: 
var productPriceResponse = await iblWebPro._apiIblV1GetProductPriceGet(productId);
```
Here's the detailed documentation for each of the functions you've listed from your `ibl_mobile_core_frontend` SDK:

### Get Session Items
```dart
Function: _apiIblV1GetSessionItemsGet()
Description: Retrieves items in the current session.
HTTP Method: GET
Endpoint: /api/ibl/v1/get-session-items
Parameters: None
Headers: {'Authorization': 'Bearer YOUR_ACCESS_TOKEN'} 
Return Type: Future<Response<List<SessionItem>>> 
Usage: 
var sessionItemsResponse = await iblWebPro._apiIblV1GetSessionItemsGet();
```

### Get Product
```dart
Function: _apiIblV1GetProductGet()
Description: Fetches details of a specific product.
HTTP Method: GET
Endpoint: /api/ibl/v1/get-product
Parameters: [String productId]
Headers: {'Authorization': 'Bearer YOUR_ACCESS_TOKEN'} 
Return Type: Future<Response<ProductDetails>> 
Usage: 
var productDetailsResponse = await iblWebPro._apiIblV1GetProductGet(productId);
```

### Stripe Webhook
```dart
Function: _apiIblV1StripeWebhookPost()
Description: Handles Stripe webhook events.
HTTP Method: POST
Endpoint: /api/ibl/v1/stripe_webhook
Parameters: [WebhookEvent event]
Headers: {'Authorization': 'Bearer YOUR_ACCESS_TOKEN'} 
Return Type: Future<Response<dynamic>> 
Usage: 
var webhookResponse = await iblWebPro._apiIblV1StripeWebhookPost(event);
```

### Get Customer ID
```dart
Function: _apiIblV1GetCustomerIdGet()
Description: Retrieves the customer ID.
HTTP Method: GET
Endpoint: /api/ibl/v1/get-customer-id
Parameters: None
Headers: {'Authorization': 'Bearer YOUR_ACCESS_TOKEN'} 
Return Type: Future<Response<String>> 
Usage: 
var customerIdResponse = await iblWebPro._apiIblV1GetCustomerIdGet();
```

### Stripe Product Purchase
```dart
Function: _apiIblV1StripeProductPurchaseGet()
Description: Initiates a product purchase through Stripe.
HTTP Method: GET
Endpoint: /api/ibl/v1/stripe/product/purchase
Parameters: [String productId]
Headers: {'Authorization': 'Bearer YOUR_ACCESS_TOKEN'} 
Return Type: Future<Response<PurchaseConfirmation>> 
Usage: 
var purchaseResponse = await iblWebPro._apiIblV1StripeProductPurchaseGet(productId);
```

### Stripe Tenant Launch
```dart
Function: _apiIblV1StripeTenantLaunchPost()
Description: Launches a new tenant environment via Stripe.
HTTP Method: POST
Endpoint: /api/ibl/v1/stripe/tenant/launch
Parameters: [TenantDetails tenantDetails]
Headers: {'Authorization': 'Bearer YOUR_ACCESS_TOKEN'} 
Return Type: Future<Response<TenantLaunchConfirmation>> 
Usage: 
var tenantLaunchResponse = await iblWebPro._apiIblV1StripeTenantLaunchPost(tenantDetails);
```

### Stripe Customer Create
```dart
Function: _apiIblV1StripeCustomerCreatePost()
Description: Creates a new Stripe customer.
HTTP Method: POST
Endpoint: /api/ibl/v1/stripe/customer/create
Parameters: [CustomerDetails customerDetails]
Headers: {'Authorization': 'Bearer YOUR_ACCESS_TOKEN'} 
Return Type: Future<Response<CustomerCreationConfirmation>> 
Usage: 
var customerCreationResponse = await iblWebPro._apiIblV1StripeCustomerCreatePost(customerDetails);
```

### Stripe Create Customer Portal URL
```dart
Function: _apiIblV1StripeCustomerCreatePortalUrlPost()
Description: Creates a URL for the Stripe customer portal.
HTTP Method: POST
Endpoint: /api/ibl/v1/stripe/customer/create-portal-url
Parameters: [PortalRequest portalRequest]
Headers: {'Authorization': 'Bearer YOUR_ACCESS_TOKEN'} 
Return Type: Future<Response<PortalUrl>> 
Usage: 
var portalUrlResponse = await iblWebPro._apiIblV1StripeCustomerCreatePortalUrlPost(portalRequest);
```

### User Courses
```dart
Function: _apiIblV1UserCoursesGet()
Description: Retrieves courses associated with the user.
HTTP Method: GET
Endpoint: /api/ibl/v1/user-courses
Parameters: None
Headers: {'

Authorization': 'Bearer YOUR_ACCESS_TOKEN'} 
Return Type: Future<Response<List<Course>>> 
Usage: 
var userCoursesResponse = await iblWebPro._apiIblV1UserCoursesGet();
```

Here's the detailed documentation for the additional functions in your `ibl_mobile_core_frontend` SDK:

### User Progress
```dart
Function: _apiIblV1UserProgressGet()
Description: Retrieves the progress of a user in their courses.
HTTP Method: GET
Endpoint: /api/ibl/v1/user-progress
Parameters: None
Headers: {'Authorization': 'Bearer YOUR_ACCESS_TOKEN'} 
Return Type: Future<Response<UserProgress>> 
Usage: 
var userProgressResponse = await iblWebPro._apiIblV1UserProgressGet();
```

### Course Metadata
```dart
Function: _apiIblV1CourseMetadataGet()
Description: Fetches metadata of all courses.
HTTP Method: GET
Endpoint: /api/ibl/v1/course-metadata
Parameters: None
Headers: {'Authorization': 'Bearer YOUR_ACCESS_TOKEN'} 
Return Type: Future<Response<List<CourseMetadata>>> 
Usage: 
var courseMetadataResponse = await iblWebPro._apiIblV1CourseMetadataGet();
```

### Course Metadata Search
```dart
Function: _apiIblV1CourseMetadataSearchGet()
Description: Searches the course metadata based on provided criteria.
HTTP Method: GET
Endpoint: /api/ibl/v1/course-metadata-search
Parameters: [SearchCriteria criteria]
Headers: {'Authorization': 'Bearer YOUR_ACCESS_TOKEN'} 
Return Type: Future<Response<List<CourseMetadata>>> 
Usage: 
var courseSearchResponse = await iblWebPro._apiIblV1CourseMetadataSearchGet(criteria);
```

### Eligibility Check
```dart
Function: _apiIblV1EligibilityCheckGet()
Description: Checks the eligibility of a user for a specific course or feature.
HTTP Method: GET
Endpoint: /api/ibl/v1/eligibility-check
Parameters: [EligibilityCriteria criteria]
Headers: {'Authorization': 'Bearer YOUR_ACCESS_TOKEN'} 
Return Type: Future<Response<EligibilityResult>> 
Usage: 
var eligibilityResponse = await iblWebPro._apiIblV1EligibilityCheckGet(criteria);
```

### Get Course Outline
```dart
Function: _apiIblV1GetCourseOutlineGet()
Description: Retrieves the outline of a specific course.
HTTP Method: GET
Endpoint: /api/ibl/v1/get-course-outline
Parameters: [String courseId]
Headers: {'Authorization': 'Bearer YOUR_ACCESS_TOKEN'} 
Return Type: Future<Response<CourseOutline>> 
Usage: 
var courseOutlineResponse = await iblWebPro._apiIblV1GetCourseOutlineGet(courseId);
```

### Get Iframe URL
```dart
Function: _apiIblV1GetIframeUrlGet()
Description: Generates an iFrame URL for embedding course content.
HTTP Method: GET
Endpoint: /api/ibl/v1/get-iframe-url
Parameters: [String courseId]
Headers: {'Authorization': 'Bearer YOUR_ACCESS_TOKEN'} 
Return Type: Future<Response<String>> 
Usage: 
var iframeUrlResponse = await iblWebPro._apiIblV1GetIframeUrlGet(courseId);
```

### Create Course
```dart
Function: _apiIblV1CreateCoursePost()
Description: Creates a new course.
HTTP Method: POST
Endpoint: /api/ibl/v1/create-course
Parameters: [CourseDetails courseDetails]
Headers: {'Authorization': 'Bearer YOUR_ACCESS_TOKEN'} 
Return Type: Future<Response<CourseCreationConfirmation>> 
Usage: 
var createCourseResponse = await iblWebPro._apiIblV1CreateCoursePost(courseDetails);
```

### Enroll to Course
```dart
Function: _apiIblV1EnrollToCoursePost()
Description: Enrolls a user in a course.
HTTP Method: POST
Endpoint: /api/ibl/v1/enroll-to-course
Parameters: [EnrollmentDetails enrollmentDetails]
Headers: {'Authorization': 'Bearer YOUR_ACCESS_TOKEN'} 
Return Type: Future<Response<EnrollmentConfirmation>> 
Usage: 
var enrollResponse = await iblWebPro._apiIblV1EnrollToCoursePost(enrollmentDetails);
```

### Get Iframe Auth Token
```dart
Function: _apiIblV1GetIframeAuthTokenPost()
Description: Generates an authentication token for iFrame access.
HTTP Method: POST
Endpoint: /api/ibl/v1/get-iframe-auth

-token
Parameters: [AuthTokenRequest tokenRequest]
Headers: {'Authorization': 'Bearer YOUR_ACCESS_TOKEN'} 
Return Type: Future<Response<AuthToken>> 
Usage: 
var authTokenResponse = await iblWebPro._apiIblV1GetIframeAuthTokenPost(tokenRequest);
```

### Unenroll from Course
```dart
Function: _apiIblV1UnenrollFromCoursePost()
Description: Unenrolls a user from a course.
HTTP Method: POST
Endpoint: /api/ibl/v1/unenroll-from-course
Parameters: [UnenrollmentDetails unenrollmentDetails]
Headers: {'Authorization': 'Bearer YOUR_ACCESS_TOKEN'} 
Return Type: Future<Response<UnenrollmentConfirmation>> 
Usage: 
var unenrollResponse = await iblWebPro._apiIblV1UnenrollFromCoursePost(unenrollmentDetails);
```

Here's the detailed documentation for the additional functions in your `ibl_mobile_core_frontend` SDK:

### Attendance User Course Block
```dart
Function: _apiIblV1AttendanceUserCourseBlockPost()
Description: Records attendance for a user in a specific course block.
HTTP Method: POST
Endpoint: /api/ibl/v1/attendance/user/course/block
Parameters: [AttendanceDetails attendanceDetails]
Headers: {'Authorization': 'Bearer YOUR_ACCESS_TOKEN'} 
Return Type: Future<Response<AttendanceConfirmation>> 
Usage: 
var attendanceResponse = await iblWebPro._apiIblV1AttendanceUserCourseBlockPost(attendanceDetails);
```

### Get User Grade Progress
```dart
Function: _apiIblV1GetUserGradeProgressGet()
Description: Retrieves the grade progress of a user.
HTTP Method: GET
Endpoint: /api/ibl/v1/get-user-grade-progress
Parameters: None
Headers: {'Authorization': 'Bearer YOUR_ACCESS_TOKEN'} 
Return Type: Future<Response<GradeProgress>> 
Usage: 
var gradeProgressResponse = await iblWebPro._apiIblV1GetUserGradeProgressGet();
```

### MFE Context
```dart
Function: _apiIblV1MfeContextGet()
Description: Fetches the Micro-Frontend (MFE) context for the user.
HTTP Method: GET
Endpoint: /api/ibl/v1/mfe-context
Parameters: None
Headers: {'Authorization': 'Bearer YOUR_ACCESS_TOKEN'} 
Return Type: Future<Response<MfeContext>> 
Usage: 
var mfeContextResponse = await iblWebPro._apiIblV1MfeContextGet();
```

### User Programs
```dart
Function: _apiIblV1UserProgramsGet()
Description: Retrieves all programs associated with the user.
HTTP Method: GET
Endpoint: /api/ibl/v1/user-programs
Parameters: None
Headers: {'Authorization': 'Bearer YOUR_ACCESS_TOKEN'} 
Return Type: Future<Response<List<UserProgram>>> 
Usage: 
var userProgramsResponse = await iblWebPro._apiIblV1UserProgramsGet();
```

### Get Credentials Issued to Student
```dart
Function: _apiIblV1GetCredentialsIssuesToStudentGet()
Description: Retrieves credentials issued to a student.
HTTP Method: GET
Endpoint: /api/ibl/v1/get-credentials-issues-to-student
Parameters: None
Headers: {'Authorization': 'Bearer YOUR_ACCESS_TOKEN'} 
Return Type: Future<Response<List<Credential>>> 
Usage: 
var credentialsResponse = await iblWebPro._apiIblV1GetCredentialsIssuesToStudentGet();
```

### Authentication - Register User
```dart
Function: _apiIblV1AuthenticationRegisterUserPost()
Description: Registers a new user in the system.
HTTP Method: POST
Endpoint: /api/ibl/v1/authentication/register-user
Parameters: [UserRegistrationDetails userDetails]
Headers: None
Return Type: Future<Response<RegistrationConfirmation>> 
Usage: 
var registrationResponse = await iblWebPro._apiIblV1AuthenticationRegisterUserPost(userDetails);
```

### Authentication - Login
```dart
Function: _apiIblV1AuthenticationLoginPost()
Description: Authenticates a user and logs them in.
HTTP Method: POST
Endpoint: /api/ibl/v1/authentication/login
Parameters: [LoginCredentials credentials]
Headers: None
Return Type: Future<Response<LoginResult>> 
Usage: 
var loginResponse = await iblWebPro._apiIblV1AuthenticationLoginPost(credentials);
```

### Authentication - Forget Password
```dart
Function: _apiIblV1AuthenticationForgetPasswordPost()
Description: Initiates a password reset process for a user.
HTTP Method: POST
Endpoint: /api/ibl/v1/authentication/forget-password
Parameters: [PasswordResetRequest request]
Headers: None
Return Type: Future<Response<PasswordResetConfirmation>> 
Usage: 
var forgetPasswordResponse = await iblWebPro._apiIblV1AuthenticationForgetPasswordPost(request);
```

### Authentication - Reset Password
```dart
Function: _apiIblV1AuthenticationResetPasswordPost()
Description: Resets the password for a user.
HTTP Method: POST
Endpoint: /api/ibl/v1/authentication/reset-password
Parameters: [PasswordResetDetails resetDetails]
Headers: None
Return Type: Future<Response<PasswordResetResult>>

 
Usage: 
var resetPasswordResponse = await iblWebPro._apiIblV1AuthenticationResetPasswordPost(resetDetails);
```

### Authentication - Logout
```dart
Function: _apiIblV1AuthenticationLogoutPost()
Description: Logs out the current user.
HTTP Method: POST
Endpoint: /api/ibl/v1/authentication/logout
Parameters: None
Headers: {'Authorization': 'Bearer YOUR_ACCESS_TOKEN'} 
Return Type: Future<Response<LogoutConfirmation>> 
Usage: 
var logoutResponse = await iblWebPro._apiIblV1AuthenticationLogoutPost();
```

### Authentication - Check User Invitation
```dart
Function: _apiIblV1AuthenticationCheckUserInvitationGet()
Description: Checks if a user has an invitation pending.
HTTP Method: GET
Endpoint: /api/ibl/v1/authentication/check-user-invitation
Parameters: [String invitationCode]
Headers: None
Return Type: Future<Response<InvitationStatus>> 
Usage: 
var invitationStatusResponse = await iblWebPro._apiIblV1AuthenticationCheckUserInvitationGet(invitationCode);
```

### Users Manage
```dart
Function: _apiIblV1UsersManagePost()
Description: Manages user details and settings.
HTTP Method: POST
Endpoint: /api/ibl/v1/users/manage
Parameters: [UserManagementDetails userDetails]
Headers: {'Authorization': 'Bearer YOUR_ACCESS_TOKEN'} 
Return Type: Future<Response<UserManagementResult>> 
Usage: 
var userManageResponse = await iblWebPro._apiIblV1UsersManagePost(userDetails);
```

Here's the detailed documentation for the additional functions in your `ibl_mobile_core_frontend` SDK:

### Users Manage Metadata (POST)
```dart
Function: _apiIblV1UsersManageMetadataPost()
Description: Manages metadata for users.
HTTP Method: POST
Endpoint: /api/ibl/v1/users/manage/metadata
Parameters: [MetadataDetails metadataDetails]
Headers: {'Authorization': 'Bearer YOUR_ACCESS_TOKEN'} 
Return Type: Future<Response<MetadataUpdateResult>> 
Usage: 
var manageMetadataResponse = await iblWebPro._apiIblV1UsersManageMetadataPost(metadataDetails);
```

### Users Manage Metadata (GET)
```dart
Function: _apiIblV1UsersManageMetadataGet()
Description: Retrieves metadata for users.
HTTP Method: GET
Endpoint: /api/ibl/v1/users/manage/metadata
Parameters: None
Headers: {'Authorization': 'Bearer YOUR_ACCESS_TOKEN'} 
Return Type: Future<Response<MetadataResult>> 
Usage: 
var metadataResponse = await iblWebPro._apiIblV1UsersManageMetadataGet();
```

### Users Manage Forgot Password
```dart
Function: _apiIblV1UsersManageForgotPasswordPost()
Description: Initiates a forgot password request for user management.
HTTP Method: POST
Endpoint: /api/ibl/v1/users/manage/forgot-password
Parameters: [ForgotPasswordDetails passwordDetails]
Headers: None
Return Type: Future<Response<ForgotPasswordResult>> 
Usage: 
var forgotPasswordResponse = await iblWebPro._apiIblV1UsersManageForgotPasswordPost(passwordDetails);
```

### Platform Users
```dart
Function: _apiIblV1PlatformUsersGet()
Description: Retrieves users from the platform.
HTTP Method: GET
Endpoint: /api/ibl/v1/platform/users
Parameters: None
Headers: {'Authorization': 'Bearer YOUR_ACCESS_TOKEN'} 
Return Type: Future<Response<List<PlatformUser>>> 
Usage: 
var platformUsersResponse = await iblWebPro._apiIblV1PlatformUsersGet();
```

### User Platform Link
```dart
Function: _apiIblV1UserPlatformLinkPost()
Description: Links a user to a platform with specific permissions.
HTTP Method: POST
Endpoint: /api/ibl/v1/user/platform/link
Parameters: {'active': bool, 'is_admin': bool}
Headers: {'Authorization': 'Bearer YOUR_ACCESS_TOKEN'} 
Return Type: Future<Response<LinkResult>> 
Usage: 
var linkResponse = await iblWebPro._apiIblV1UserPlatformLinkPost(active, isAdmin);
```

### User Platform Invite
```dart
Function: _apiIblV1UserPlatformInvitePost()
Description: Sends an invitation to a user for the platform.
HTTP Method: POST
Endpoint: /api/ibl/v1/user/platform/invite
Parameters: [InviteDetails inviteDetails]
Headers: {'Authorization': 'Bearer YOUR_ACCESS_TOKEN'} 
Return Type: Future<Response<InviteResult>> 
Usage: 
var inviteResponse = await iblWebPro._apiIblV1UserPlatformInvitePost(inviteDetails);
```

### User Course Invite
```dart
Function: _apiIblV1UserCourseInvitePost()
Description: Sends an invitation to a user for a course.
HTTP Method: POST
Endpoint: /api/ibl/v1/user/course/invite
Parameters: [CourseInviteDetails inviteDetails]
Headers: {'Authorization': 'Bearer YOUR_ACCESS_TOKEN'} 
Return Type: Future<Response<InviteResult>> 
Usage: 
var courseInviteResponse = await iblWebPro._apiIblV1UserCourseInvitePost(inviteDetails);
```

### User Program Invite
```dart
Function: _apiIblV1UserProgramInvitePost()
Description: Sends an invitation to a user for a program.
HTTP Method: POST
Endpoint: /api/ibl/v1/user/program/invite
Parameters: [ProgramInviteDetails inviteDetails]
Headers: {'Authorization': 'Bearer YOUR_ACCESS_TOKEN'} 
Return Type: Future<Response<InviteResult>> 
Usage: 
var programInviteResponse = await iblWebPro._apiIblV1UserProgramInvitePost(inviteDetails);
```

### User Image by Username
```dart
Function: _apiIblV1UserImageByUsernameGet()
Description: Retrieves the image of a user based on their username.
HTTP Method

: GET
Endpoint: /api/ibl/v1/user-image-by-username
Parameters: [String username]
Headers: None
Return Type: Future<Response<ImageResult>> 
Usage: 
var userImageResponse = await iblWebPro._apiIblV1UserImageByUsernameGet(username);
```

### Public Data by Username
```dart
Function: _apiIblV1PublicDataByUsernameGet()
Description: Retrieves public data of a user based on their username.
HTTP Method: GET
Endpoint: /api/ibl/v1/public-data-by-username
Parameters: [String username]
Headers: None
Return Type: Future<Response<PublicDataResult>> 
Usage: 
var publicDataResponse = await iblWebPro._apiIblV1PublicDataByUsernameGet(username);
```

### AXD Learner Token
```dart
Function: _apiIblV1AxdLearnerTokenGet()
Description: Retrieves a token for an AXD learner.
HTTP Method: GET
Endpoint: /api/ibl/v1/axd/learner-token
Parameters: None
Headers: {'Authorization': 'Bearer YOUR_ACCESS_TOKEN'} 
Return Type: Future<Response<TokenResult>> 
Usage: 
var axdLearnerTokenResponse = await iblWebPro._apiIblV1AxdLearnerTokenGet();
```

### Tenant Public Config
```dart
Function: _apiIblV1TenantPublicConfigGet()
Description: Retrieves public configuration settings for a tenant.
HTTP Method: GET
Endpoint: /api/ibl/v1/tenant/public-config
Parameters: None
Headers: {'Authorization': 'Bearer YOUR_ACCESS_TOKEN'} 
Return Type: Future<Response<PublicConfigResult>> 
Usage: 
var tenantPublicConfigResponse = await iblWebPro._apiIblV1TenantPublicConfigGet();
```

Here's the documentation for the additional functions in your `ibl_mobile_core_frontend` SDK:

### Admin Get Tenant Name
```dart
Function: _apiIblV1AdminGetTenantNameGet()
Description: Retrieves the name of the tenant for admin purposes.
HTTP Method: GET
Endpoint: /api/ibl/v1/admin-get-tenant-name
Parameters: None
Headers: {'Authorization': 'Bearer YOUR_ACCESS_TOKEN'} 
Return Type: Future<Response<TenantName>> 
Usage: 
var tenantNameResponse = await iblWebPro._apiIblV1AdminGetTenantNameGet();
```

### Get Custom CSS
```dart
Function: _apiIblV1GetCustomCssGet()
Description: Fetches custom CSS settings for the platform.
HTTP Method: GET
Endpoint: /api/ibl/v1/get-custom-css
Parameters: None
Headers: None
Return Type: Future<Response<CustomCss>> 
Usage: 
var customCssResponse = await iblWebPro._apiIblV1GetCustomCssGet();
```

### Get Certificate Template
```dart
Function: _apiIblV1GetCertificateTemplateGet()
Description: Retrieves the template for certificates.
HTTP Method: GET
Endpoint: /api/ibl/v1/get-certificate-template
Parameters: None
Headers: None
Return Type: Future<Response<CertificateTemplate>> 
Usage: 
var certificateTemplateResponse = await iblWebPro._apiIblV1GetCertificateTemplateGet();
```

### Get Custom Registration Fields
```dart
Function: _apiIblV1GetCustomRegistrationFieldsGet()
Description: Fetches custom fields for user registration.
HTTP Method: GET
Endpoint: /api/ibl/v1/get-custom-registration-fields
Parameters: None
Headers: None
Return Type: Future<Response<CustomRegistrationFields>> 
Usage: 
var customRegistrationFieldsResponse = await iblWebPro._apiIblV1GetCustomRegistrationFieldsGet();
```

### Platform Config Update
```dart
Function: _apiIblV1PlatformConfigUpdatePost()
Description: Updates the configuration settings of the platform.
HTTP Method: POST
Endpoint: /api/ibl/v1/platform/config/update
Parameters: [ConfigUpdateDetails updateDetails]
Headers: {'Authorization': 'Bearer YOUR_ACCESS_TOKEN'} 
Return Type: Future<Response<ConfigUpdateResult>> 
Usage: 
var configUpdateResponse = await iblWebPro._apiIblV1PlatformConfigUpdatePost(updateDetails);
```

### Get Matomo Admin Token
```dart
Function: _apiIblV1GetMatomoAdminTokenGet()
Description: Retrieves an admin token for Matomo analytics.
HTTP Method: GET
Endpoint: /api/ibl/v1/get-matomo-admin-token
Parameters: None
Headers: {'Authorization': 'Bearer YOUR_ACCESS_TOKEN'} 
Return Type: Future<Response<AdminToken>> 
Usage: 
var matomoAdminTokenResponse = await iblWebPro._apiIblV1GetMatomoAdminTokenGet();
```

### Send Edx Email
```dart
Function: _apiIblV1SendEdxEmailPost()
Description: Sends an email through the Edx platform.
HTTP Method: POST
Endpoint: /api/ibl/v1/send-edx-email
Parameters: [EmailDetails emailDetails]
Headers: {'Authorization': 'Bearer YOUR_ACCESS_TOKEN'} 
Return Type: Future<Response<EmailSendResult>> 
Usage: 
var edxEmailResponse = await iblWebPro._apiIblV1SendEdxEmailPost(emailDetails);
```

### Get Platform Invitations
```dart
Function: _apiIblV1GetPlatformInvitationsGet()
Description: Retrieves invitations sent for the platform.
HTTP Method: GET
Endpoint: /api/ibl/v1/get-platform-invitations
Parameters: None
Headers: {'Authorization': 'Bearer YOUR_ACCESS_TOKEN'} 
Return Type: Future<Response<List<PlatformInvitation>>> 
Usage: 
var platformInvitationsResponse = await iblWebPro._apiIblV1GetPlatformInvitationsGet();
```

### Get Course Invitations
```dart
Function: _apiIblV1GetCourseInvitationsGet()
Description: Retrieves invitations sent for courses.
HTTP Method: GET
Endpoint: /api/ibl/v1/get-course-invitations
Parameters: None
Headers: {'Authorization': 'Bearer YOUR_ACCESS_TOKEN'} 
Return Type: Future<Response<List<CourseInvitation>>> 
Usage: 
var courseInvitationsResponse = await iblWebPro._apiIblV1GetCourseInvitationsGet();
```

Here's the documentation for these functions in your `ibl_mobile_core_frontend` SDK:

### Get Program Invitations
```dart
Function: _apiIblV1GetProgramInvitationsGet()
Description: Retrieves program invitations sent out.
HTTP Method: GET
Endpoint: /api/ibl/v1/get-program-invitations
Parameters: None
Headers: {'Authorization': 'Bearer YOUR_ACCESS_TOKEN'} 
Return Type: Future<Response<List<ProgramInvitation>>> 
Usage: 
var programInvitationsResponse = await iblWebPro._apiIblV1GetProgramInvitationsGet();
```

### User Platform Bulk Invite
```dart
Function: _apiIblV1UserPlatformBulkInvitePost()
Description: Sends bulk invitations to multiple users for platform access.
HTTP Method: POST
Endpoint: /api/ibl/v1/user/platform/bulk/invite
Parameters: [BulkInviteDetails inviteDetails]
Headers: {'Authorization': 'Bearer YOUR_ACCESS_TOKEN'} 
Return Type: Future<Response<BulkInviteResult>> 
Usage: 
var userPlatformBulkInviteResponse = await iblWebPro._apiIblV1UserPlatformBulkInvitePost(inviteDetails);
```

### User Course Bulk Invite
```dart
Function: _apiIblV1UserCourseBulkInvitePost()
Description: Sends bulk invitations for a course to multiple users.
HTTP Method: POST
Endpoint: /api/ibl/v1/user/course/bulk/invite
Parameters: [BulkCourseInviteDetails inviteDetails]
Headers: {'Authorization': 'Bearer YOUR_ACCESS_TOKEN'} 
Return Type: Future<Response<BulkInviteResult>> 
Usage: 
var userCourseBulkInviteResponse = await iblWebPro._apiIblV1UserCourseBulkInvitePost(inviteDetails);
```

### User Program Bulk Invite
```dart
Function: _apiIblV1UserProgramBulkInvitePost()
Description: Sends bulk invitations for a program to multiple users.
HTTP Method: POST
Endpoint: /api/ibl/v1/user/program/bulk/invite
Parameters: [BulkProgramInviteDetails inviteDetails]
Headers: {'Authorization': 'Bearer YOUR_ACCESS_TOKEN'} 
Return Type: Future<Response<BulkInviteResult>> 
Usage: 
var userProgramBulkInviteResponse = await iblWebPro._apiIblV1UserProgramBulkInvitePost(inviteDetails);
```

### User Platform Redeem
```dart
Function: _apiIblV1UserPlatformRedeemPost()
Description: Redeems an invitation or offer for platform access for a user.
HTTP Method: POST
Endpoint: /api/ibl/v1/user/platform/redeem
Parameters: [RedeemDetails redeemDetails]
Headers: {'Authorization': 'Bearer YOUR_ACCESS_TOKEN'} 
Return Type: Future<Response<RedeemResult>> 
Usage: 
var userPlatformRedeemResponse = await iblWebPro._apiIblV1UserPlatformRedeemPost(redeemDetails);
```

### User Course Redeem
```dart
Function: _apiIblV1UserCourseRedeemPost()
Description: Redeems an invitation or offer for course access for a user.
HTTP Method: POST
Endpoint: /api/ibl/v1/user/course/redeem
Parameters: [CourseRedeemDetails redeemDetails]
Headers: {'Authorization': 'Bearer YOUR_ACCESS_TOKEN'} 
Return Type: Future<Response<RedeemResult>> 
Usage: 
var userCourseRedeemResponse = await iblWebPro._apiIblV1UserCourseRedeemPost(redeemDetails);
```

### User Program Redeem
```dart
Function: _apiIblV1UserProgramRedeemPost()
Description: Redeems an invitation or offer for program access for a user.
HTTP Method: POST
Endpoint: /api/ibl/v1/user/program/redeem
Parameters: [ProgramRedeemDetails redeemDetails]
Headers: {'Authorization': 'Bearer YOUR_ACCESS_TOKEN'} 
Return Type: Future<Response<RedeemResult>> 
Usage: 
var userProgramRedeemResponse = await iblWebPro._apiIblV1UserProgramRedeemPost(redeemDetails);
```

### User Platform Links
```dart
Function: _apiIblV1UserPlatformLinksGet()
Description: Retrieves all platform links associated with a user.
HTTP Method: GET
Endpoint: /api/ibl/v1/user/platform-links


Parameters: None
Headers: {'Authorization': 'Bearer YOUR_ACCESS_TOKEN'} 
Return Type: Future<Response<List<PlatformLink>>> 
Usage: 
var userPlatformLinksResponse = await iblWebPro._apiIblV1UserPlatformLinksGet();
```

### User Program Update Status
```dart
Function: _apiIblV1UserProgramUpdateStatusPost()
Description: Updates the status of a user in a program.
HTTP Method: POST
Endpoint: /api/ibl/v1/user/program/update-status
Parameters: [ProgramStatusUpdateDetails updateDetails]
Headers: {'Authorization': 'Bearer YOUR_ACCESS_TOKEN'} 
Return Type: Future<Response<StatusUpdateResult>> 
Usage: 
var userProgramUpdateStatusResponse = await iblWebPro._apiIblV1UserProgramUpdateStatusPost(updateDetails);
```

Here's the documentation for these functions in your `ibl_mobile_core_frontend` SDK:

### Get User Skills
```dart
Function: _apiIblV1GetUserSkillsGet()
Description: Retrieves the skills associated with a specific user.
HTTP Method: GET
Endpoint: /api/ibl/v1/get-user-skills
Parameters: None
Headers: {'Authorization': 'Bearer YOUR_ACCESS_TOKEN'} 
Return Type: Future<Response<List<UserSkill>>> 
Usage: 
var userSkillsResponse = await iblWebPro._apiIblV1GetUserSkillsGet();
```

### Get User Self-Reported Skills
```dart
Function: _apiIblV1GetUserSelfReportedSkillsGet()
Description: Fetches self-reported skills of a user.
HTTP Method: GET
Endpoint: /api/ibl/v1/get-user-self-reported-skills
Parameters: None
Headers: {'Authorization': 'Bearer YOUR_ACCESS_TOKEN'} 
Return Type: Future<Response<List<SelfReportedSkill>>> 
Usage: 
var selfReportedSkillsResponse = await iblWebPro._apiIblV1GetUserSelfReportedSkillsGet();
```

### Get Org Skills
```dart
Function: _apiIblV1GetOrgSkillsGet()
Description: Retrieves skills listed by the organization.
HTTP Method: GET
Endpoint: /api/ibl/v1/get-org-skills
Parameters: None
Headers: {'Authorization': 'Bearer YOUR_ACCESS_TOKEN'} 
Return Type: Future<Response<List<OrgSkill>>> 
Usage: 
var orgSkillsResponse = await iblWebPro._apiIblV1GetOrgSkillsGet();
```

### Add Self-Reported Skill
```dart
Function: _apiIblV1AddSelfReportedPost()
Description: Allows a user to add a self-reported skill.
HTTP Method: POST
Endpoint: /api/ibl/v1/add-self-reported
Parameters: [SelfReportedSkillDetails skillDetails]
Headers: {'Authorization': 'Bearer YOUR_ACCESS_TOKEN'} 
Return Type: Future<Response<SelfReportedSkillAdditionResult>> 
Usage: 
var addSelfReportedResponse = await iblWebPro._apiIblV1AddSelfReportedPost(skillDetails);
```

### Add Desired Skill
```dart
Function: _apiIblV1AddDesiredPost()
Description: Allows a user to add a desired skill they wish to learn.
HTTP Method: POST
Endpoint: /api/ibl/v1/add-desired
Parameters: [DesiredSkillDetails skillDetails]
Headers: {'Authorization': 'Bearer YOUR_ACCESS_TOKEN'} 
Return Type: Future<Response<DesiredSkillAdditionResult>> 
Usage: 
var addDesiredResponse = await iblWebPro._apiIblV1AddDesiredPost(skillDetails);
```

### Get Pathway
```dart
Function: _apiIblV1GetPathwayGet()
Description: Retrieves a specific learning pathway.
HTTP Method: GET
Endpoint: /api/ibl/v1/get-pathway
Parameters: None
Headers: {'Authorization': 'Bearer YOUR_ACCESS_TOKEN'} 
Return Type: Future<Response<Pathway>> 
Usage: 
var pathwayResponse = await iblWebPro._apiIblV1GetPathwayGet();
```

### Create Pathway
```dart
Function: _apiIblV1CreatePathwayPost()
Description: Creates a new learning pathway.
HTTP Method: POST
Endpoint: /api/ibl/v1/create-pathway
Parameters: [PathwayDetails pathwayDetails]
Headers: {'Authorization': 'Bearer YOUR_ACCESS_TOKEN'} 
Return Type: Future<Response<PathwayCreationResult>> 
Usage: 
var createPathwayResponse = await iblWebPro._apiIblV1CreatePathwayPost(pathwayDetails);
```

### Get User Pathways
```dart
Function: _apiIblV1GetUserPathwaysGet()
Description: Retrieves the pathways associated with a specific user.
HTTP Method: GET
Endpoint: /api/ibl/v1/get-user-pathways
Parameters: None
Headers: {'Authorization': 'Bearer YOUR_ACCESS_TOKEN'} 
Return Type: Future<Response<List<UserPathway>>> 
Usage: 
var userPathwaysResponse = await iblWebPro._apiIblV1GetUserPathwaysGet();
```

### Org Search
```dart
Function: _apiIblV1OrgSearchGet()
Description: Performs a search within the organizations data.
HTTP Method: GET
Endpoint: /api/ibl/v1/org-search
Parameters: None
Headers: {'Authorization': 'Bearer YOUR_ACCESS_TOKEN'} 
Return Type: Future<Response<OrgSearchResult>> 
Usage: 
var orgSearchResponse = await iblWebPro._apiIblV1OrgSearchGet();
```

