# To effectively utilize the ibl_mobile_core_frontend SDK in your Flutter application, you need to follow a few steps for setup and usage. Below, I will provide a clear and concise documentation with code snippets for integrating and using both IblWebPro and IblAxdPro services from the SDK.

## Setup and Integration
## Add the SDK to pubspec.yaml:
## Include ibl_mobile_core_frontend in your pubspec.yaml file under dependencies:
```
dependencies:
  flutter:
    sdk: flutter
  ibl_mobile_core_frontend: ^1.0.2+1
  # ... other dependencies ...
Run flutter pub get:
```
# After editing your pubspec.yaml, run flutter pub get in your terminal to fetch the SDK.

# Import the SDK in Your Dart File:
## In the Dart file where you want to use the SDK services, import the necessary parts of the SDK:

```
import 'package:ibl_mobile_core_frontend/ibl_web_pro.swagger.dart';
import 'package:ibl_mobile_core_frontend/ibl_axd_pro.swagger.dart';
```

# Using IblWebPro Service
## To create an instance of IblWebPro and make a login request:

```
import 'package:ibl_mobile_core_frontend/ibl_web_pro.swagger.dart';
import 'package:chopper/chopper.dart';

void main() async {
  var iblWebPro = IblWebPro.create(baseUrl: Uri.parse('http://your-base-url.com'));

  var response = await iblWebPro.apiIblV1AuthenticationLoginPost(
    username: 'your_username',
    password: 'your_password'
  );

  if (response.isSuccessful) {
    // Handle successful response
  } else {
    // Handle error
  }
}
```
# Using IblAxdPro Service
## For using IblAxdPro, follow a similar pattern:

```
import 'package:ibl_mobile_core_frontend/ibl_axd_pro.swagger.dart';
import 'package:chopper/chopper.dart';

void main() async {
  var iblAxdPro = IblAxdPro.create(baseUrl: Uri.parse('http://your-base-url.com'));

  // Replace with appropriate parameters
  var response = await iblAxdPro.apiAiMentorOrgsOrgSessionsPost(
    org: 'your_org',
    body: ChatSessionRequest(/* parameters */)
  );

  if (response.isSuccessful) {
    // Handle successful response
  } else {
    // Handle error
  }
}
```

# General Notes
```
Replace 'http://your-base-url.com' with the actual base URL of your backend service.
Handle responses and errors appropriately as per your application's logic.
Ensure that all required parameters are correctly passed to the function calls.
```

