# Callinng ibl-axd endpoints using the passed tokens
```
import 'package:ibl_mobile_core_frontend/ibl_axd_pro.swagger.dart';
import 'package:chopper/chopper.dart';

class TokenInterceptor implements RequestInterceptor {
  final String authToken;

  TokenInterceptor(this.authToken);

  @override
  FutureOr<Request> onRequest(Request request) async {
    final headers = {
      ...request.headers,
      'Authorization': 'Token $authToken',
    };
    return request.copyWith(headers: headers);
  }
}

void main() async {
  await performRequest('yourAuthToken'); // Pass the auth token here
}

Future<void> performRequest(String authToken) async {
  var iblAxdPro = IblAxdPro.create(
    baseUrl: Uri.parse('https://data.mentor.iblai.tech/wp-json'),
    interceptors: [TokenInterceptor(authToken)],
  );

  // Example of how to use the functions
  var mentorListResponse = await listMentors(iblAxdPro, 'orgId', 1, 10, 'userId');
  var suggestedMentorsResponse = await suggestedMentors(iblAxdPro, 'orgId');
  // Handle responses...
}

// Function to list mentors
Future<PaginatedMentorList> listMentors(
  IblAxdPro iblAxdPro,
  String org,
  int page,
  int pageSize,
  String userId,
) async {
  var response = await iblAxdPro._apiAiMentorOrgsOrgUsersUserIdGet(
    org: org,
    page: page,
    pageSize: pageSize,
    userId: userId,
  );

  if (response.isSuccessful && response.body != null) {
    return response.body!;
  } else {
    throw Exception('Failed to fetch mentor list');
  }
}

// Function to suggest mentors (assuming this function fetches featured mentors)
Future<PaginatedMentorList> suggestedMentors(IblAxdPro iblAxdPro, String org) async {
  // Pass featured=true in the query
  var response = await iblAxdPro._apiAiMentorOrgsOrgUsersUserIdGet(
    org: org,
    page: 1,
    pageSize: 10,
    userId: 'featured=true',
  );

  if (response.isSuccessful && response.body != null) {
    return response.body!;
  } else {
    throw Exception('Failed to fetch suggested mentors');
  }
}

// Function to create a mentor with settings
Future<MentorFromTemplate> createMentorWithSettings(
  IblAxdPro iblAxdPro,
  String org,
  MentorFromTemplateWithSettingRequest body,
) async {
  var response = await iblAxdPro.apiAiMentorOrgsOrgMentorWithSettingsPost(
    org: org,
    body: body,
  );

  if (response.isSuccessful && response.body != null) {
    return response.body!;
  } else {
    throw Exception('Failed to create mentor with settings');
  }
}

```